Region class

Constructors

Region({required String id, required Path path, String? title, required String pathString, required Color color, Color? strokeColor, num? strokeWidth})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
path Path
final
pathString String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor Color?
final
strokeWidth num?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited