Region class

Constructors

Region({required String id, required ModelPath path, String? title, required String pathString, required Color color})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
path ModelPath
final
pathString String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited